adviz
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Get startd quickly and see exmaples below

## Install

``` sh
pip install adviz
```

## How to use

Count unique values in a list of items

``` python
value_counts_plus(list('aaaaaaaaabbbbcccddddddddddeeeeeeeeeeeeffffggghhhiijjjjkkkllllmmmmmmmnnooop'))
```

<style type="text/css">
#T_f4f7a_row0_col1, #T_f4f7a_row0_col3 {
  background-color: #cebc63;
  color: #000000;
}
#T_f4f7a_row0_col2, #T_f4f7a_row0_col4, #T_f4f7a_row8_col1, #T_f4f7a_row8_col3, #T_f4f7a_row9_col1, #T_f4f7a_row9_col3 {
  background-color: #00224e;
  color: #f1f1f1;
}
#T_f4f7a_row1_col1, #T_f4f7a_row1_col3 {
  background-color: #9d9576;
  color: #f1f1f1;
}
#T_f4f7a_row1_col2, #T_f4f7a_row1_col4 {
  background-color: #293f6e;
  color: #f1f1f1;
}
#T_f4f7a_row2_col1, #T_f4f7a_row2_col3 {
  background-color: #878478;
  color: #f1f1f1;
}
#T_f4f7a_row2_col2, #T_f4f7a_row2_col4 {
  background-color: #51586d;
  color: #f1f1f1;
}
#T_f4f7a_row3_col1, #T_f4f7a_row3_col3 {
  background-color: #5e636f;
  color: #f1f1f1;
}
#T_f4f7a_row3_col2, #T_f4f7a_row3_col4 {
  background-color: #6b6d72;
  color: #f1f1f1;
}
#T_f4f7a_row4_col1, #T_f4f7a_row4_col3, #T_f4f7a_row5_col1, #T_f4f7a_row5_col3, #T_f4f7a_row6_col1, #T_f4f7a_row6_col3, #T_f4f7a_row7_col1, #T_f4f7a_row7_col3 {
  background-color: #013271;
  color: #f1f1f1;
}
#T_f4f7a_row4_col2, #T_f4f7a_row4_col4 {
  background-color: #787877;
  color: #f1f1f1;
}
#T_f4f7a_row5_col2, #T_f4f7a_row5_col4 {
  background-color: #888578;
  color: #f1f1f1;
}
#T_f4f7a_row6_col2, #T_f4f7a_row6_col4 {
  background-color: #979177;
  color: #f1f1f1;
}
#T_f4f7a_row7_col2, #T_f4f7a_row7_col4 {
  background-color: #a89e73;
  color: #f1f1f1;
}
#T_f4f7a_row8_col2, #T_f4f7a_row8_col4 {
  background-color: #b5a86f;
  color: #f1f1f1;
}
#T_f4f7a_row9_col2, #T_f4f7a_row9_col4 {
  background-color: #c2b369;
  color: #000000;
}
#T_f4f7a_row10_col1, #T_f4f7a_row10_col2, #T_f4f7a_row10_col3, #T_f4f7a_row10_col4 {
  background-color: #fee838;
  color: #000000;
}
</style>
<table id="T_f4f7a">
  <caption><h2>Counts of <b>data</b></h2></caption>
  <thead>
    <tr>
      <th class="blank level0" >&nbsp;</th>
      <th id="T_f4f7a_level0_col0" class="col_heading level0 col0" >data</th>
      <th id="T_f4f7a_level0_col1" class="col_heading level0 col1" >count</th>
      <th id="T_f4f7a_level0_col2" class="col_heading level0 col2" >cum_count</th>
      <th id="T_f4f7a_level0_col3" class="col_heading level0 col3" >perc</th>
      <th id="T_f4f7a_level0_col4" class="col_heading level0 col4" >cum_perc</th>
    </tr>
  </thead>
  <tbody>
    <tr>
      <th id="T_f4f7a_level0_row0" class="row_heading level0 row0" >0</th>
      <td id="T_f4f7a_row0_col0" class="data row0 col0" >e</td>
      <td id="T_f4f7a_row0_col1" class="data row0 col1" >12</td>
      <td id="T_f4f7a_row0_col2" class="data row0 col2" >12</td>
      <td id="T_f4f7a_row0_col3" class="data row0 col3" >16.2%</td>
      <td id="T_f4f7a_row0_col4" class="data row0 col4" >16.2%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row1" class="row_heading level0 row1" >1</th>
      <td id="T_f4f7a_row1_col0" class="data row1 col0" >d</td>
      <td id="T_f4f7a_row1_col1" class="data row1 col1" >10</td>
      <td id="T_f4f7a_row1_col2" class="data row1 col2" >22</td>
      <td id="T_f4f7a_row1_col3" class="data row1 col3" >13.5%</td>
      <td id="T_f4f7a_row1_col4" class="data row1 col4" >29.7%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row2" class="row_heading level0 row2" >2</th>
      <td id="T_f4f7a_row2_col0" class="data row2 col0" >a</td>
      <td id="T_f4f7a_row2_col1" class="data row2 col1" >9</td>
      <td id="T_f4f7a_row2_col2" class="data row2 col2" >31</td>
      <td id="T_f4f7a_row2_col3" class="data row2 col3" >12.2%</td>
      <td id="T_f4f7a_row2_col4" class="data row2 col4" >41.9%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row3" class="row_heading level0 row3" >3</th>
      <td id="T_f4f7a_row3_col0" class="data row3 col0" >m</td>
      <td id="T_f4f7a_row3_col1" class="data row3 col1" >7</td>
      <td id="T_f4f7a_row3_col2" class="data row3 col2" >38</td>
      <td id="T_f4f7a_row3_col3" class="data row3 col3" >9.5%</td>
      <td id="T_f4f7a_row3_col4" class="data row3 col4" >51.4%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row4" class="row_heading level0 row4" >4</th>
      <td id="T_f4f7a_row4_col0" class="data row4 col0" >b</td>
      <td id="T_f4f7a_row4_col1" class="data row4 col1" >4</td>
      <td id="T_f4f7a_row4_col2" class="data row4 col2" >42</td>
      <td id="T_f4f7a_row4_col3" class="data row4 col3" >5.4%</td>
      <td id="T_f4f7a_row4_col4" class="data row4 col4" >56.8%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row5" class="row_heading level0 row5" >5</th>
      <td id="T_f4f7a_row5_col0" class="data row5 col0" >f</td>
      <td id="T_f4f7a_row5_col1" class="data row5 col1" >4</td>
      <td id="T_f4f7a_row5_col2" class="data row5 col2" >46</td>
      <td id="T_f4f7a_row5_col3" class="data row5 col3" >5.4%</td>
      <td id="T_f4f7a_row5_col4" class="data row5 col4" >62.2%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row6" class="row_heading level0 row6" >6</th>
      <td id="T_f4f7a_row6_col0" class="data row6 col0" >j</td>
      <td id="T_f4f7a_row6_col1" class="data row6 col1" >4</td>
      <td id="T_f4f7a_row6_col2" class="data row6 col2" >50</td>
      <td id="T_f4f7a_row6_col3" class="data row6 col3" >5.4%</td>
      <td id="T_f4f7a_row6_col4" class="data row6 col4" >67.6%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row7" class="row_heading level0 row7" >7</th>
      <td id="T_f4f7a_row7_col0" class="data row7 col0" >l</td>
      <td id="T_f4f7a_row7_col1" class="data row7 col1" >4</td>
      <td id="T_f4f7a_row7_col2" class="data row7 col2" >54</td>
      <td id="T_f4f7a_row7_col3" class="data row7 col3" >5.4%</td>
      <td id="T_f4f7a_row7_col4" class="data row7 col4" >73.0%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row8" class="row_heading level0 row8" >8</th>
      <td id="T_f4f7a_row8_col0" class="data row8 col0" >c</td>
      <td id="T_f4f7a_row8_col1" class="data row8 col1" >3</td>
      <td id="T_f4f7a_row8_col2" class="data row8 col2" >57</td>
      <td id="T_f4f7a_row8_col3" class="data row8 col3" >4.1%</td>
      <td id="T_f4f7a_row8_col4" class="data row8 col4" >77.0%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row9" class="row_heading level0 row9" >9</th>
      <td id="T_f4f7a_row9_col0" class="data row9 col0" >g</td>
      <td id="T_f4f7a_row9_col1" class="data row9 col1" >3</td>
      <td id="T_f4f7a_row9_col2" class="data row9 col2" >60</td>
      <td id="T_f4f7a_row9_col3" class="data row9 col3" >4.1%</td>
      <td id="T_f4f7a_row9_col4" class="data row9 col4" >81.1%</td>
    </tr>
    <tr>
      <th id="T_f4f7a_level0_row10" class="row_heading level0 row10" >10</th>
      <td id="T_f4f7a_row10_col0" class="data row10 col0" >Others:</td>
      <td id="T_f4f7a_row10_col1" class="data row10 col1" >14</td>
      <td id="T_f4f7a_row10_col2" class="data row10 col2" >74</td>
      <td id="T_f4f7a_row10_col3" class="data row10 col3" >18.9%</td>
      <td id="T_f4f7a_row10_col4" class="data row10 col4" >100.0%</td>
    </tr>
  </tbody>
</table>
